netapp_ontap.models.anti_ransomware_volume_workload_surge_statistics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.anti_ransomware_volume_workload_surge_statistics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AntiRansomwareVolumeWorkloadSurgeStatisticsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AntiRansomwareVolumeWorkloadSurgeStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_create_peak_rate_per_minute: Size GET`

    Peak rate of file creates per minute in the workload of the volume during surge.

    Example: 10

  `file_delete_peak_rate_per_minute: Size GET`

    Peak rate of file deletes per minute in the workload of the volume during surge.

    Example: 50

  `file_rename_peak_rate_per_minute: Size GET`

    Peak rate of file renames per minute in the workload of the volume during surge.

    Example: 30

  `high_entropy_data_write_peak_percent: Size GET`

    Peak percentage of high entropy data writes in the volume during surge.

    Example: 30

  `high_entropy_data_write_peak_rate_kb_per_minute: Size GET`

    Peak high entropy data write rate in the volume during surge, in KBs per minute.

    Example: 2500

  `time: ImpreciseDateTime GET`

    Timestamp at which the first surge in the volume's workload is observed.

    Example: 2021-12-01T17:46:20.000+0000